pub struct CallTreeManager { /* private fields */ }Expand description
Global call tree manager
Implementations
Sourceimpl CallTreeManager
impl CallTreeManager
Sourcepub fn function_enter(
&self,
function_address: u64,
call_site: u64,
function_info: Option<FunctionInfo>,
arguments: Vec<CapturedArgument>,
register_context: Option<RegisterContext>,
) -> Result<NodeId>
pub fn function_enter( &self, function_address: u64, call_site: u64, function_info: Option<FunctionInfo>, arguments: Vec<CapturedArgument>, register_context: Option<RegisterContext>, ) -> Result<NodeId>
Handle function entry
Sourcepub fn function_enter_fast_path(
&self,
function_address: u64,
call_site: u64,
) -> Result<NodeId>
pub fn function_enter_fast_path( &self, function_address: u64, call_site: u64, ) -> Result<NodeId>
Handle function entry - fast path (minimal overhead) This is optimized for the case where argument capture is disabled
Sourcepub fn function_exit(&self, function_address: u64) -> Result<()>
pub fn function_exit(&self, function_address: u64) -> Result<()>
Handle function exit
Sourcepub fn function_exit_with_return_value(
&self,
_function_address: u64,
return_value: Option<ArgumentValue>,
) -> Result<()>
pub fn function_exit_with_return_value( &self, _function_address: u64, return_value: Option<ArgumentValue>, ) -> Result<()>
Handle function exit with return value
Sourcepub fn function_exit_fast_path(&self, _function_address: u64) -> Result<()>
pub fn function_exit_fast_path(&self, _function_address: u64) -> Result<()>
Handle function exit - fast path (minimal overhead) This is optimized for the case where argument capture is disabled
Sourcepub fn mark_pthread_create(&self, node_id: NodeId) -> Result<()>
pub fn mark_pthread_create(&self, node_id: NodeId) -> Result<()>
Mark a node as pthread_create and register pending thread creation
Sourcepub fn thread_started(&self, new_thread_id: ThreadId) -> Result<()>
pub fn thread_started(&self, new_thread_id: ThreadId) -> Result<()>
Handle new thread start (consume pending thread creation)
Sourcepub fn get_statistics(&self) -> CallTreeStatistics
pub fn get_statistics(&self) -> CallTreeStatistics
Get statistics
Sourcepub fn get_thread_ids(&self) -> Vec<ThreadId> ⓘ
pub fn get_thread_ids(&self) -> Vec<ThreadId> ⓘ
Get all thread IDs
Sourcepub fn get_thread_tree(
&self,
thread_id: ThreadId,
) -> Option<Arc<RwLock<ThreadCallTree>>>
pub fn get_thread_tree( &self, thread_id: ThreadId, ) -> Option<Arc<RwLock<ThreadCallTree>>>
Get thread tree for a specific thread