Crash Handler Module
This module provides crash detection and detailed crash reporting functionality. It installs signal handlers for common crash signals only if no existing handlers are present, and generates comprehensive crash reports including the current call stack.
Structs
- Crash
Info - Crash information structure
- Stack
Frame - Stack frame information
Functions
- cleanup_
crash_ handler - Cleanup crash handler (restore original handlers)
- init_
crash_ handler - Initialize crash handler
- is_
crash_ handler_ enabled - Check if crash handler is enabled
- reinforce_
crash_ handlers - Reinforce crash handlers (reinstall to override any handlers set after initialization)